"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureDir = exports.canAccess = void 0;
const fs_1 = require("fs");
/** @private */
async function canAccess(p) {
    try {
        await fs_1.promises.access(p);
        return true;
    }
    catch (_) {
        return false;
    }
}
exports.canAccess = canAccess;
/** @private */
async function ensureDir(dir) {
    if (!(await canAccess(dir))) {
        await fs_1.promises.mkdir(dir, { recursive: true });
        return;
    }
    // dir already exists, make sure it isn't a file
    const stat = await fs_1.promises.stat(dir);
    if (!stat.isDirectory()) {
        throw new Error(`'${dir}' is not a directory`);
    }
}
exports.ensureDir = ensureDir;
//# sourceMappingURL=fs.js.map